@@ -421,7 +421,7 @@ dominance.manual <- function(x, out = NULL, digits = 3, write = NULL, append = T
       # Send R output to textfile
       sink(file = write, append = ifelse(isTRUE(file.exists(write)), append, FALSE), type = "output", split = FALSE)
 
-      if (append && isTRUE(file.exists(write))) { write("", file = write, append = TRUE) }
+      if (isTRUE(append && file.exists(write))) { write("", file = write, append = TRUE) }
 
       # Print object
       print(object, check = FALSE)
